"use strict";

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

/**
 * Returns new Array with dimensions from said parameters
 * 
 * @param {Array} arr
 * @param {Integer} breadth
 * @param {Integer} depth
 * @param {*} defaultVal
 * @returns {Array}
 */

function getValue(value, fallback) {
  if (value === undefined) return fallback;

  return value;
}

function arrayShape(arr) {
  var breadth = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  var depth = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
  var defaultVal = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;

  if (!Array.isArray(arr) && typeof arr !== "string") return arr;
  if (breadth < 0 || depth < 0) return arr;

  var breadthArr = [].concat(_toConsumableArray(Array(breadth)));
  var depthArr = [].concat(_toConsumableArray(Array(depth)));

  return breadthArr.map(function (item, idx) {
    var arrIdx = arr[idx];

    if (depth > 1) {
      return depthArr.map(function (depthItem, depthIdx) {
        var isArr = Array.isArray(arrIdx);

        if (!isArr && depthIdx === 0) return getValue(arrIdx, defaultVal);
        if (isArr) return getValue(arrIdx[depthIdx], defaultVal);

        return defaultVal;
      });
    } else if (depth === 1) {
      if (Array.isArray(arrIdx)) return arrIdx.shift();
    }

    return getValue(arrIdx, defaultVal);
  });
}

module.exports = arrayShape;