"use strict";

/**
 * `caesar's cipher` takes in a string and "encrypts" it by shifting the letters by a predefined amount. This function will implement a ROT13 cipher, meaning each letter will shift 13 places in the alphabet.
 *
 * Examples: A -> N
 *           B -> O
 *           C -> P
 *           Z -> M
 *           Q -> D
 *           R -> E
 *           S -> F
 *
 * @param {msg} A String to encrypt.
 * @returns {String} the encrypted message.
 */
function caesarsCipher(msg) {
  var upperCaseStartCharCode = "A".charCodeAt(0);
  var upperCaseEndCharCode = "Z".charCodeAt(0);
  var lowerCaseStartCharCode = "a".charCodeAt(0);
  var lowerCaseEndCharCode = "z".charCodeAt(0);

  var map = Array.prototype.map;
  var cryptedMessage = map.call(msg, function (char) {
    var charCode = char.charCodeAt(0);
    var cipheredChar = char;

    if (charCode >= upperCaseStartCharCode && charCode <= upperCaseEndCharCode) {
      var cipheredCode = (charCode - upperCaseStartCharCode + 13) % 26 + upperCaseStartCharCode;
      cipheredChar = String.fromCharCode(cipheredCode);
    } else if (charCode >= lowerCaseStartCharCode && charCode <= lowerCaseEndCharCode) {
      var _cipheredCode = (charCode - lowerCaseStartCharCode + 13) % 26 + lowerCaseStartCharCode;
      cipheredChar = String.fromCharCode(_cipheredCode);
    }

    return cipheredChar;
  }).join("");
  return cryptedMessage || "";
}

module.exports = caesarsCipher;