"use strict";

/**
 * Returns a function that invoked with params either:
 * - invokes func with params, if params length matches func's arity
 * - a new (curried) function, accepting func's remaining parameters
 *
 * @param {Number} a
 * @param {Number} b
 * @returns {Number}
 */

function curry(func) {
  if (typeof func !== "function") {
    throw new Error("func is not a function");
  }

  var arity = func.length;

  if (arity === 0) {
    return func;
  }

  for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    args[_key - 1] = arguments[_key];
  }

  if (args.length < arity) {
    return curry.bind.apply(curry, [null, func].concat(args));
  }

  return func.apply(undefined, args);
}

module.exports = curry;