"use strict";

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

/**
 * Check if all properties on the provided parameters are equal.
 * This should recurse through all objects in the parameters' object graph.
 * Equivalence should be asserted on numbers, strings, and arrays in the object graph.
 * @param {Object} objOne the first object
 * @param {Object} objTwo the second object
 * @return {Boolean} result
 */

// test to check if obj are defined
var isDefined = function isDefined(obj) {
  return (typeof obj === "undefined" ? "undefined" : _typeof(obj)) == "object" && obj !== null;
};

// array test helper function
var isArray = function isArray(obj) {
  return Array.isArray(obj);
};

// pure object test helper function
var isPlainObject = function isPlainObject(obj) {
  return !isArray(obj) && (typeof obj === "undefined" ? "undefined" : _typeof(obj)) === "object";
};

// Object compare helper function
var objectCompare = function objectCompare(objOne, objTwo) {
  var keys1 = Object.keys(objOne);
  var keys2 = Object.keys(objTwo);

  if (keys1.length !== keys2.length) {
    return false;
  }

  var keysMatch = keys1.every(function (key) {
    return keys2.includes(key);
  });
  if (!keysMatch) {
    return false;
  }

  return keys1.every(function (key) {
    return baseDeepCompare(objOne[key], objTwo[key]);
  });
};

// Array compare helper function
var arrayCompare = function arrayCompare(objOne, objTwo) {
  if (objOne.length !== objTwo.length) {
    return false;
  }

  return objOne.every(function (el, index) {
    return baseDeepCompare(el, objTwo[index]);
  });
};

/*
 * Recursive deep compare call
 */
var baseDeepCompare = function baseDeepCompare(objOne, objTwo) {
  if ((typeof objOne === "undefined" ? "undefined" : _typeof(objOne)) !== (typeof objTwo === "undefined" ? "undefined" : _typeof(objTwo))) {
    return false;
  }

  if (isArray(objOne)) {
    return arrayCompare(objOne, objTwo);
  }

  if (isPlainObject(objOne)) {
    return objectCompare(objOne, objTwo);
  }

  return objOne === objTwo;
};

/*
* Function entry point
* checks for null and undefined
*/
function deepCompare(objOne, objTwo) {
  if (objOne === objTwo) {
    return true;
  }

  return baseDeepCompare(objOne, objTwo);
}

module.exports = deepCompare;