"use strict";

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

/**
 * Search through an object/array and return a list of all objects that match the
 * test function
 * @param {Object/Array} input
 * @param {function} test function
 * @return {Array} list of all objects that match the test. Order not important
 */

function deepSearch(input, test) {
  if (!input || !test) return function () {
    throw new Error("Please provide arguments");
  };else if ((typeof input === "undefined" ? "undefined" : _typeof(input)) !== "object" || typeof test !== "function") return function () {
    throw new Error("Please provide an array or an object and a function as the two arguments.");
  };

  var results = [];
  var dataQueue = [input];

  while (dataQueue.length) {
    var isObj = dataQueue.shift();

    if (Array.isArray(isObj)) {
      isObj.forEach(function (element) {
        dataQueue.push(element);
      });
    } else if (!Array.isArray(isObj) && (typeof isObj === "undefined" ? "undefined" : _typeof(isObj)) === "object") {
      if (test(isObj)) results.push(isObj);

      for (var key in isObj) {
        dataQueue.push(isObj[key]);
      }
    }
  }

  return results;
}

module.exports = deepSearch;