"use strict";

var flattenArray = require("./flattenArray");
var getKeyValuePairs = require("./getKeyValuePairs");
var hasNestedProperties = require("./hasNestedProperties");
var isObject = require("./isObject");

// Write function which takes a nested object and flattens it
//
// flattenNestedObject({ "a" : 1, "b" : { "c" : { "d" : { "e" : 1, "f" : 2 } } } }, '-') => {a: 1, "b-c-d-e": 1, "b-c-d-f": 2}
// flattenNestedObject({ "a" : 1, "b" : { "c" : { "d" : { "e" : 1, "f" : 2 } } } }) => {a: 1, "b.c.d.e": 1, "b.c.d.f": 2}

function flattenNestedObject(object) {
  var delimiter = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : ".";

  if (!isObject(object)) {
    throw new Error("First parameter must be an object");
  }

  if (!hasNestedProperties(object)) {
    return object;
  }

  return getKeyValuePairs(object, delimiter).reduce(toObject, {});
}

function toObject(acc, _ref) {
  var key = _ref.key,
      value = _ref.value;

  acc[key] = value;

  return acc;
}

module.exports = flattenNestedObject;