"use strict";

/**
 * Can be used to compose functions into one large function. When calling the composed function,
 * the value will be put into the first function of @param funcs. The result of this will be put in
 * the function after that and so on. This is the reverse of {@link compose}.
 * @param {Function[]} funcs: functions that will be composed to a new function.
 * @returns {Function} Composed function.
 */

function flow() {
  for (var _len = arguments.length, funcs = Array(_len), _key = 0; _key < _len; _key++) {
    funcs[_key] = arguments[_key];
  }

  funcs.forEach(function (func) {
    if (typeof func !== "function") throw "not a function";
  });
  if (funcs.length === 0) {
    return function (initialValue) {
      return initialValue;
    };
  }
  return function (initialValue) {
    var value = initialValue;
    funcs.forEach(function (f) {
      value = f(value);
    });
    return value;
  };
}

module.exports = flow;