"use strict";

/**
 * Returns the truth value of the biconditional (logical equivalence).
 * https://en.wikipedia.org/wiki/Logical_biconditional
 * (p → q) ∧ (q → p)
 *
 * @param {*} antecendent
 * @param {*} consequent
 * @return {Boolean}
 *
 */

function getBiconditional() {
  var antecendent = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  var consequent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

  // First let cast the arguments to booleans
  var a = !!antecendent;
  var b = !!consequent;
  // Then apply the logical operation
  return a && b || !a && !b;
}

module.exports = getBiconditional;