"use strict";

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

/**
 * Accepts two matrices A and B and returns the matrix A*B.
 *
 * @param {Array} A An array of arrays, where each inner array is an array of
 *                  Numbers.
 * @param {Array} B An array of arrays, where each inner array is an array of
 *                  Numbers.
 *
 * @returns {Array} An array of arrays, where each inner array is an array of
 *                  Numbers.
 *
 * @throws {InvalidDimensions} If A is an n * m matrix and B is an i * j
 *                             matrix, then if m does not equal i an
 *                             `InvalidDimensions` error will be thrown.
 *
 * Example: A = [[2, 2], [0, 2]] | 2 2 |
 *                               | 0 2 |
 *
 *          B = [[3, 0], [1, 1]] | 3 0 |
 *                               | 1 1 |
 *
 *          matMul(A, B) returns [[8, 2], [2, 2]] | 8 2 |
 *                                                | 2 2 |
 */

function matMul(A, B) {
  if (B.length != A[0].length) throw "InvalidDimensions";
  var dotProductRows = [];

  var _loop = function _loop(row) {
    var dotProductColumn = B[0].reduce(function (p, c, bCol) {
      return [].concat(_toConsumableArray(p), [A[row].reduce(function (pp, cc, aCol) {
        return pp + cc * B[aCol][bCol];
      }, 0)]);
    }, []);
    dotProductRows.push(dotProductColumn);
  };

  for (var row = 0; row < A.length; row++) {
    _loop(row);
  }
  return dotProductRows;
}

module.exports = matMul;