"use strict";

/**
 * Returns bitwise OR of all parameters.
 * Given only booleans, the result is a logical OR.
 * @param  {...number|boolean|array} args - array arguments can contain either numbers, booleans or arrays.
 * @return {number|boolean}
 */

var isNumber = require("./isNumber.js");
var isArray = require("./isArray.js");

var allBoolean = true;

function checkTypes(input) {
  input.forEach(function (item) {
    if (!isNumber(item) && typeof item !== "boolean" && !isArray(item)) {
      throw Error("Invalid type");
    } else if (isArray(item)) {
      checkTypes(item);
    } else if (isNumber(item)) {
      allBoolean = false;
    }
  });
}

function convertToBinary(input) {
  return parseInt(Number(input).toString(2));
}

function singleBitwiseOr(a, b) {
  var digitArray = (a + b).toString().split("");
  var binaryArray = digitArray.map(function (digit) {
    return digit > 0 ? 1 : 0;
  });
  return parseInt(binaryArray.join(""), 2);
}

function addBinary(input) {
  if (isArray(input)) {
    return input.reduce(function (accumulator, current) {
      if (isArray(current)) {
        current = convertToBinary(addBinary(current));
      } else {
        current = convertToBinary(current);
      }
      accumulator = convertToBinary(accumulator);

      return singleBitwiseOr(current, accumulator);
    }, 0);
  } else {
    return input;
  }
}

function or() {
  for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
    args[_key] = arguments[_key];
  }

  checkTypes(args);

  if (allBoolean) return addBinary(args) === 1;
  return addBinary(args);
}

module.exports = or;