"use strict";

/**
 * Wrap a function f and return a new function g that when invoked,
 * will call f with the arguments provided to `partial` prepended
 * to the argument list provided to g.
 * @param {Function} f
 * @param {...any} fixedArgs
 * @return {Function} wrapped function
 */

function partial(f) {
  for (var _len = arguments.length, fixedArgs = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    fixedArgs[_key - 1] = arguments[_key];
  }

  if (typeof f !== "function") {
    throw new TypeError("The first argument of partial must be a function");
  }
  if (fixedArgs.length <= 0) {
    return f;
  }
  return function () {
    for (var _len2 = arguments.length, moreArgs = Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      moreArgs[_key2] = arguments[_key2];
    }

    return f.apply(this, fixedArgs.concat(moreArgs));
  };
}

module.exports = partial;