"use strict";

/**
 * Removes items from an array by identity. (This method does not mutate the array).
 * @param {Array} array from which will be copied without provided items
 * @param {...any} itemsToRemove these items will be missing in the created array.
 * @returns Array new array that does not contain items in itemsToRemove
 */

function without(array) {
  for (var _len = arguments.length, itemsToRemove = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    itemsToRemove[_key - 1] = arguments[_key];
  }

  if (!Array.isArray(array)) {
    throw "First argument is not an array";
  } else if (itemsToRemove.length === 0) {
    throw "List of items to remove is empty";
  }
  var ret = [];
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = array[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var i = _step.value;

      if (!itemsToRemove.includes(i)) {
        ret.push(i);
      }
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }

  if (ret.length === array.length) {
    return array;
  }
  return ret;
}

module.exports = without;